package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppletTrain;

/**
 * 服务培训Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface AppletTrainMapper 
{
    /**
     * 查询服务培训
     * 
     * @param id 服务培训主键
     * @return 服务培训
     */
    public AppletTrain selectAppletTrainById(Long id);

    /**
     * 查询服务培训列表
     * 
     * @param appletTrain 服务培训
     * @return 服务培训集合
     */
    public List<AppletTrain> selectAppletTrainList(AppletTrain appletTrain);

    /**
     * 新增服务培训
     * 
     * @param appletTrain 服务培训
     * @return 结果
     */
    public int insertAppletTrain(AppletTrain appletTrain);

    /**
     * 修改服务培训
     * 
     * @param appletTrain 服务培训
     * @return 结果
     */
    public int updateAppletTrain(AppletTrain appletTrain);

    /**
     * 删除服务培训
     * 
     * @param id 服务培训主键
     * @return 结果
     */
    public int deleteAppletTrainById(Long id);

    /**
     * 批量删除服务培训
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletTrainByIds(Long[] ids);
}
